@@ -1,6 +1,6 @@
 /*
 --          This file is part of the New World OS and Objectify projects
---            Copyright (C) 2005, 2006, 2007, 2008, 2009  QRW Software
+--         Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010  QRW Software
 --               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2009-10-06 08:06:23 -0600 (Tue, 06 Oct 2009) $
---   $Revision: 4384 $
+--   $Date: 2010-09-05 13:15:19 -0600 (Sun, 05 Sep 2010) $
+--   $Revision: 4676 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -458,19 +458,21 @@ bool nwos_find_private_class_definition(char* name, ObjRef* class_ref)
 }
 
 
-#if 0
 bool nwos_find_class_definition(char* name, ObjRef* class_ref)
 {
     bool result = true;
 
-    if (is_void_reference(&nwos_private_class_definition_class_ref) || !nwos_find_private_class_definition(name, class_ref))
+    if (nwos_in_public_mode())
     {
 	result = nwos_find_public_class_definition(name, class_ref);
     }
+    else
+    {
+	result = nwos_find_private_class_definition(name, class_ref);
+    }
 
     return result;
 }
-#endif
 
 
 void nwos_read_class_definition(ObjRef* ref, C_struct_Class_Definition* class_def)
@@ -626,8 +628,7 @@ static void get_file_references()
 	copy_reference(&file_references[1], &public_file_references[1]);
 	copy_reference(&file_references[2], &public_file_references[2]);
 
-#ifndef PUBLIC_MODE
-	if (nwos_find_private_class_definition("FILE", &class_ref))       /* are there any private files? */
+	if (!nwos_in_public_mode() && nwos_find_private_class_definition("FILE", &class_ref))       /* are there any private files? */
 	{
 	    nwos_read_object_headers_from_disk(&class_ref, &header);
 
@@ -662,7 +663,6 @@ static void get_file_references()
 		copy_reference(&file_references[i], &class_ref);
 	    }
 	}
-#endif
     }
 
 #if 0
@@ -705,9 +705,8 @@ ObjRef* nwos_get_file_class_reference()
     {
 	get_file_references();
     }
-#ifndef PUBLIC_MODE
     /* if storage is writable check to see if an updated file class has been created since this was first initialized */
-    else if (nwos_is_writable() && nwos_reference_type(&file_references[2]) == Public_Reference)
+    else if (!nwos_in_public_mode() && nwos_is_writable() && nwos_reference_type(&file_references[2]) == Public_Reference)
     {
 	ObjRef class_ref;
 	EveryObject header;
@@ -723,7 +722,6 @@ ObjRef* nwos_get_file_class_reference()
 	    }
 	}
     }
-#endif
 
     return &file_references[2];
 }
